| Title: | Rangeland Health and Condition |
|---|---|
| Description: | The evaluation criteria of rangeland health, condition and landscape function analysis based on species diversity and functional diversity of rangeland plant communities. |
| Authors: | Zahra Heidari Ghahfarrokhi [aut, cre]
|
| Maintainer: | Zahra Heidari Ghahfarrokhi <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.1.0 |
| Built: | 2026-05-22 06:58:11 UTC |
| Source: | https://github.com/cran/RHC |
A dataset containing canopy cover information.
data(canopy_oc_file)data(canopy_oc_file)
This function creates plots to compare evaluation criteria of landscape function analysis (LFA), rangeland health and condition.
plot_RHC(evaluation.criteria, selected_columns = NULL, ncol = 4)plot_RHC(evaluation.criteria, selected_columns = NULL, ncol = 4)
evaluation.criteria |
A data frame containing standardized data from the first function. |
selected_columns |
A vector of column indices specifying which criteria to plot. If NULL, all columns will be plotted. |
ncol |
Number of columns for arranging the plots. Default is 4. |
plot_RHC |
A function that takes standardized data and generates evaluation plots for different criteria of landscape function analysis (LFA), rangeland health and condition. |
The function takes the output from RHC_function and creates evaluation plots for different criteria.
A list of evaluation criteria(attributes) plots.
data(canopy_oc_file) data(trait_file) final_data_st <- prepare_RHC_data(canopy_oc_file, trait_file) evaluation.criteria <- RHC_function(final_data_st) # Plot all columns plots_all <- plot_RHC(evaluation.criteria, ncol = 4) # Plot specific columns selected_columns <- c(4, 8) plots_selected <- plot_RHC(evaluation.criteria, selected_columns, ncol = 2)data(canopy_oc_file) data(trait_file) final_data_st <- prepare_RHC_data(canopy_oc_file, trait_file) evaluation.criteria <- RHC_function(final_data_st) # Plot all columns plots_all <- plot_RHC(evaluation.criteria, ncol = 4) # Plot specific columns selected_columns <- c(4, 8) plots_selected <- plot_RHC(evaluation.criteria, selected_columns, ncol = 2)
This function creates graphs for the inputs of the RHC_function model.
final_data_st |
A data frame containing standardized data from the first function. |
row_indices |
A vector of row indices specifying which rows to use for creating sample plots. |
plot_title_prefix |
A prefix for the plot titles (default is "Sample"). |
ncol |
Number of columns for arranging the plots. Default is 3. |
The function takes input data and specific row indices, creates sample charts, and returns the plots.
A list of sample charts.
data(canopy_oc_file) data(trait_file) final_data_st <- prepare_RHC_data(canopy_oc_file, trait_file) row_indices <- 1:17 plots.samples <- plot_samples(final_data_st, row_indices, plot_title_prefix = "Sample", ncol = 3)data(canopy_oc_file) data(trait_file) final_data_st <- prepare_RHC_data(canopy_oc_file, trait_file) row_indices <- 1:17 plots.samples <- plot_samples(final_data_st, row_indices, plot_title_prefix = "Sample", ncol = 3)
This function prepares input data for the evaluation criteria of landscape function analysis (LFA), rangeland health and condition.
prepare_RHC_data(canopy_oc_file, trait_file)prepare_RHC_data(canopy_oc_file, trait_file)
canopy_oc_file |
A data frame containing canopy cover and soil organic carbon data. |
trait_file |
A data frame containing plant species trait data. |
The function takes canopy cover, soil organic carbon (OC), and plant species trait data, and returns standardized data.
Note: The first row of the input data matrix (canopy_oc_file) must be the reference sample, and the second column must contain the OC data, and the canopy cover must be entered as a relative value.
A standardized data frame for further analysis using Min-Max Normalization.
data(canopy_oc_file) data(trait_file) final_data_st <- prepare_RHC_data(canopy_oc_file, trait_file)data(canopy_oc_file) data(trait_file) final_data_st <- prepare_RHC_data(canopy_oc_file, trait_file)
This function calculates attributes of landscape function analysis (LFA), rangeland health and condition.
RHC_function(final_data_st)RHC_function(final_data_st)
final_data_st |
A data frame containing standardized data from the first function. |
The function takes standardized data, performs predictions using pre-trained models, and returns the results.
The attributes of landscape function analysis (LFA), rangeland health and condition.
data(canopy_oc_file) data(trait_file) final_data_st <- prepare_RHC_data(canopy_oc_file, trait_file) evaluation.criteria <- RHC_function(final_data_st)data(canopy_oc_file) data(trait_file) final_data_st <- prepare_RHC_data(canopy_oc_file, trait_file) evaluation.criteria <- RHC_function(final_data_st)
A dataset containing trait information.
data(trait_file)data(trait_file)